@@ -33,7 +33,7 @@ void init_cell(void)
     makeatom("nil", SIMP);	//address = 0
     makeatom("yes", SIMP);	//address = 2
     makeatom("no", SIMP);	//address = 4
-    makeatom("end_of_file", SIMP);	//address = 6
+    makeatom("end_of_file", SYS);	//address = 6
     makeatom("<undef>", SIMP);	//address = 8
     makeatom("!", SYS);		//address = 10
     makeatom(",", OPE);		//address = 12
@@ -413,24 +413,6 @@ int makesocket(int sockfd, int type, const char *name, int listenfd)
     return (addr);
 }
 
-int makecurl(CURL * curl, int type, const char *name)
-{
-    int addr;
-    char *str;
-
-    addr = freshcell();
-    SET_TAG(addr, STREAM);
-    SET_CURL(addr, curl);	/* curl */
-    SET_OPT(addr, type);	/* NPL_CURL */
-    str = (char *) malloc(strlen(name) + 1);
-    if (str == NULL)
-	exception(SYSTEM_ERR, makestr("makecurl"), NIL, 0);
-    heap[addr].name = str;
-    strcpy(heap[addr].name, name);	/* ip address */
-    SET_AUX(addr, NPL_OPEN);	/* NPL_OPEN/NPL_CLOSE initial value is NPL_OPEN */
-    return (addr);
-}
-
 
 
 //stack
