@@ -8,7 +8,6 @@ written by kenichi sasagawa 2016/9~
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
-#include <curl/curl.h>
 
 /*
 memory map
@@ -17,7 +16,7 @@ address
  5,000,001 - 30,000,000  working area 
 30,000,001 - 32,000,000  variant area
 */
-#define VERSION     4.61
+#define VERSION     4.72
 #define CELLSIZE    30000000  // if raspberry PI set smaller size.
 #define HEAPSIZE     5000000
 #define FREESIZE         500
@@ -28,7 +27,7 @@ address
 #define NTTBASE 1000
 #define RECORDMAX 12
 #define ATOMSIZE 2048
-#define BUFSIZE 2048
+#define BUFSIZE 65536
 #define STRSIZE 2048
 #define CTRLSTK 10
 #define PARASIZE 100
@@ -119,7 +118,6 @@ typedef struct {
                 FILE    *port;
                 int record;
                 int socket;
-                CURL *curl;
             } car;
             union{
                 int intnum;
@@ -346,6 +344,7 @@ extern char parent_buffer[BUFSIZE][PARASIZE];
 extern char child_buffer[BUFSIZE];
 extern int child_buffer_pos;
 extern int child_buffer_end;
+extern int dp_trace;
 
 /* multi-thread */
 extern pthread_mutex_t mutex;
@@ -763,7 +762,6 @@ int ateqsmaller(int x, int y);
 int bcons(int car, int cdr);
 int b_abolish(int arglist, int rest, int th);
 int b_abort(int arglist, int rest, int th);
-int b_add_curl_header(int arglist, int rest, int th);
 int b_n_after_cut(int arglist, int rest, int th);
 int b_ansi_cup(int arglist, int rest, int th);
 int b_ansi_cuu(int arglist, int rest, int th);
@@ -815,7 +813,6 @@ int b_clause(int arglist, int rest, int th);
 int b_n_clause_with_arity(int arglist, int rest, int th);
 int b_create_client_socket(int arglist, int rest, int th);
 int b_close(int arglist, int rest, int th);
-int b_close_curl(int arglist, int rest, int th);
 int b_close_socket(int arglist, int rest, int th);
 int b_compare(int arglist, int rest, int th);
 int b_n_compiler_anonymous(int arglist, int rest, int th);
@@ -826,7 +823,6 @@ int b_consult(int arglist, int rest, int th);
 int b_constant(int arglist, int rest, int th);
 int b_copy_term(int arglist, int rest, int th);
 int b_create(int arglist, int rest, int th);
-int b_create_client_curl(int arglist, int rest, int th);
 int b_create_server_socket(int arglist, int rest, int th);
 int b_ctr_set(int arglist, int rest, int th);
 int b_ctr_dec(int arglist, int rest, int th);
@@ -855,12 +851,13 @@ int b_dp_prove(int arglist ,int rest, int th);
 int b_dp_and(int arglist, int rest, int th);
 int b_dp_or(int arglist, int rest, int th);
 int b_dp_transfer(int arglist, int rest, int th);
-int b_dp_receive(int arglist ,int rest, int th);
 int b_dp_compile(int arglist, int rest, int th);
 int b_dp_consult(int arglist, int rest, int th);
 int b_dp_reconsult(int arglist, int rest, int th);
 int b_dp_setid(int arglist, int rest, int th);
 int b_dp_senderr(int arglist, int rest, int th);
+int b_dp_trace(int arglist, int rest, int th);
+int b_dp_notrace(int arglist, int rest, int th);
 int b_dup(int arglist, int rest, int th);
 int b_dynamic(int arglist, int rest, int th);
 int b_n_dynamic_predicate(int arglist, int rest, int th);
@@ -980,7 +977,6 @@ int b_repeat(int arglist, int rest, int th);
 int b_reset_op(int arglist, int rest, int th);
 int b_retract(int arglist, int rest, int th);
 int b_retrieveh(int arglist, int rest, int th);
-int b_recv_curl(int arglist, int rest, int th);
 int b_recv_socket(int arglist, int rest, int th);
 int b_n_reconsult_predicate(int arglist, int rest, int th);
 int b_n_reconsult_abolish(int arglist, int rest, int th);
@@ -993,10 +989,8 @@ int b_see(int arglist, int rest, int th);
 int b_seeing(int arglist, int rest, int th);
 int b_seen(int arglist, int rest, int th);
 int b_select(int arglist, int rest, int th);
-int b_send_curl(int arglist, int rest, int th);
 int b_send_socket(int arglist, int rest, int th);
 int b_setof(int arglist, int rest, int th);
-int b_set_curl_option(int arglist, int rest, int th);
 int b_set_input(int arglist, int rest, int th);
 int b_set_output(int arglist, int rest, int th);
 int b_set_prolog_flag(int arglist, int rest, int th);
@@ -1258,7 +1252,6 @@ int makeope(char *name);
 int makebinbigx(char *bignum);
 int makecomp(char *name);
 int makecopy(int x);
-int makecurl(CURL *curl, int type, const char *name);
 int makeexspec(int old_spec, int spec);
 int makeflt(double floatn);
 int makeint(int num);
