@@ -10,7 +10,6 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include <curl/curl.h>
 #include "npl.h"
 
 int b_atom_concat(int arglist, int rest, int th)
@@ -2257,184 +2256,6 @@ int b_format(int arglist, int rest, int th)
     return (NO);
 }
 
-//------------------https curl----------------
-
-
-size_t write_callback(void *ptr, size_t size, size_t nmemb, void *userdata)
-{
-    strncat((char *) userdata, (char *) ptr, size * nmemb);	// store recieved data
-    return size * nmemb;
-}
-
-int b_create_client_curl(int arglist, int rest, int th)
-{
-    int n, arg1, arg2, ind;
-    CURL *curl;
-
-    n = length(arglist);
-    ind = makeind("create_client_curl", n, th);
-    if (n == 2) {
-	arg1 = car(arglist);
-	arg2 = cadr(arglist);
-	if (!wide_variable_p(arg1))
-	    exception(NOT_STREAM, ind, arg1, th);
-	if (!stringp(arg2))
-	    exception(NOT_STR, ind, arg2, th);
-
-	curl = curl_easy_init();
-	if (!curl) {
-	    exception(SYSTEM_ERR, ind, NIL, th);
-	}
-
-	curl_easy_setopt(curl, CURLOPT_URL, GET_NAME(arg2));
-	if (unify(arg1, makecurl(curl, NPL_CURL, GET_NAME(arg2)), th) ==
-	    YES)
-	    return (prove_all(rest, sp[th], th));
-	else
-	    return (NO);
-    }
-    exception(ARITY_ERR, ind, arglist, th);
-    return (NO);
-}
-
-int b_send_curl(int arglist, int rest, int th)
-{
-    int n, arg1, arg2, ind;
-    CURL *curl;
-
-    n = length(arglist);
-    ind = makeind("send_curl", n, th);
-    if (n == 2) {
-	arg1 = car(arglist);
-	arg2 = cadr(arglist);
-	if (!streamp(arg1))
-	    exception(NOT_STREAM, ind, arg1, th);
-	if (!stringp(arg2))
-	    exception(NOT_STR, ind, arg2, th);
-
-	curl = GET_CURL(arg1);
-	curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_callback);
-	curl_easy_setopt(curl, CURLOPT_POST, 1L);
-	curl_easy_setopt(curl, CURLOPT_POSTFIELDS, GET_NAME(arg2));
-	return (prove_all(rest, sp[th], th));
-    }
-    exception(ARITY_ERR, ind, arglist, th);
-    return (NO);
-}
-
-int b_recv_curl(int arglist, int rest, int th)
-{
-    int n, arg1, arg2, ind;
-    char response_data[STRSIZE] = { 0 };
-    CURL *curl;
-
-    n = length(arglist);
-    ind = makeind("recv_curl", n, th);
-    if (n == 2) {
-	arg1 = car(arglist);
-	arg2 = cadr(arglist);
-	if (!streamp(arg1))
-	    exception(NOT_STREAM, ind, arg1, th);
-	if (!wide_variable_p(arg2))
-	    exception(NOT_VAR, ind, arg2, th);
-
-	curl = GET_CURL(arg1);
-	curl_easy_setopt(curl, CURLOPT_WRITEDATA, response_data);
-	curl_easy_perform(curl);
-	if (unify(arg2, makestr(response_data), th) == YES)
-	    return (prove_all(rest, sp[th], th));
-	else
-	    return (NO);
-    }
-    exception(ARITY_ERR, ind, arglist, th);
-    return (NO);
-}
-
-
-int b_close_curl(int arglist, int rest, int th)
-{
-    int n, arg1, ind;
-
-    n = length(arglist);
-    ind = makeind("close_curl", n, th);
-    if (n == 1) {
-	arg1 = car(arglist);
-	if (!streamp(arg1))
-	    exception(NOT_STREAM, ind, arg1, th);
-	curl_easy_cleanup(GET_CURL(arg1));
-	return (prove_all(rest, sp[th], th));
-    }
-    exception(ARITY_ERR, ind, arglist, th);
-    return (NO);
-}
-
-
-int b_set_curl_option(int arglist, int rest, int th)
-{
-    int n, arg1, arg2, ind, header, post, get, timeout, var;
-    CURL *curl;
-
-    n = length(arglist);
-    ind = makeind("set_curl_option", n, th);
-
-    if (n == 2) {
-	arg1 = car(arglist);
-	arg2 = cadr(arglist);
-	if (!streamp(arg1))
-	    exception(NOT_STREAM, ind, arg1, th);
-
-	curl = GET_CURL(arg1);
-	var = makevariant(th);
-	header = list2(makepred("header"), var);
-	post = list2(makepred("method"), makeconst("post"));
-	get = list2(makepred("get"), makeconst("get"));
-	timeout = list2(makepred("timeout"), var);
-	if (unify(arg2, header, th) == YES) {
-	    curl_easy_setopt(curl, CURLOPT_HTTPHEADER, GET_NAME(var));
-	} else if (unify(arg2, post, th) == YES) {
-	    curl_easy_setopt(curl, CURLOPT_POST, 1L);
-	} else if (unify(arg2, get, th) == YES) {
-	    curl_easy_setopt(curl, CURLOPT_HTTPGET, 1L);
-	} else if (unify(arg2, timeout, th) == YES) {
-	    long timeout = GET_INT(var);
-	    curl_easy_setopt(curl, CURLOPT_TIMEOUT, timeout);
-	} else {
-	    exception(SYSTEM_ERR, ind, NIL, th);
-	    return (NO);
-	}
-	return (prove_all(rest, sp[th], th));
-    }
-    exception(ARITY_ERR, ind, arglist, th);
-    return (NO);
-}
-
-
-
-int b_add_curl_header(int arglist, int rest, int th)
-{
-    int n, arg1, arg2, ind;
-    CURL *curl;
-    struct curl_slist *headers = NULL;
-
-    n = length(arglist);
-    ind = makeind("add_curl_header", n, th);
-
-    if (n == 2) {
-	arg1 = car(arglist);
-	arg2 = cadr(arglist);
-	if (!streamp(arg1))
-	    exception(NOT_STREAM, ind, arg1, th);
-	if (!stringp(arg2))
-	    exception(NOT_STR, ind, arg2, th);
-
-	curl = GET_CURL(arg1);
-	headers = curl_slist_append(headers, GET_NAME(arg2));
-	curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
-	return (prove_all(rest, sp[th], th));
-    }
-    exception(ARITY_ERR, ind, arglist, th);
-    return (NO);
-}
 
 int b_string_atom(int arglist, int rest, int th)
 {
