@@ -77,10 +77,8 @@ char builtin[BUILTIN_NUMBER][30] = {
     { "peek_code" }, { "peek_char" }, { "peek_byte" },
     { "stream_property" }, { "dynamic" },
     { "create_client_socket" }, { "create_server_socket" },
-    { "recv_socket" }, { "close_socket" },
-    { "create_client_curl" }, { "send_curl" }, { "recv_curl" },
-    { "close_curl" }, { "initialization" },
-    { "set_curl_option" }, { "add_curl_header" }, { "string_atom" },
+    { "recv_socket" }, { "close_socket" }, { "initialization" },
+    { "string_atom" },
     { "label" }, { "all_different" },
 };
 
@@ -100,8 +98,8 @@ char extended[EXTENDED_NUMBER][30] = {
     { "compile_file" }, { "timer_microseconds" }, { "with" },
     { "existerrors" }, { "dp_create" }, { "dp_consult" }, { "dp_countup" },
     { "dp_transfer" }, { "dp_and" }, { "dp_or" }, { "dp_halt" },
-    { "dp_receive" }, { "dp_reconsult" }, { "dp_setid" }, { "dp_senderr" },
-    { "dp_compile" }, { "dp_prove" }, { "dp_close" }, 
+    { "dp_reconsult" }, { "dp_setid" }, { "dp_senderr" },
+    { "dp_compile" }, { "dp_prove" }, { "dp_close" }, { "dp_trace" }, { "dp_notrace" },
     { "mt_create" }, { "mt_close" }, { "mt_and" }, { "mt_or" },
     { "mt_prove" }, { "cinline" }, { "check_file" }, { "cdeclare" },
     { "clibrary" },
